*************************************************************************
***THIS FILE GENERATES THE THREE DATASETS USED IN GERBER ET AL. (2011)***
***PERSONALITY AND PARTICIPATION IN POLITICAL PROCESSES******************
*************************************************************************

clear
set mem 700m
set matsize 800
set more off

*************************************
***** CCAP PRIVATE (VALIDATED) ******
*************************************
*Analysis based on two private "modules." Thus two datasets need to be stacked. 
*The provided vote history files include all individuals surveyed for that module. 
*Additionally there was an error in the income measure and weights were not included. 
*This code stacks the vote history data files, matches them back to the "matched" (to the target sampling frame) module datasets 
*It then drops all cases not matched to the voter rolls as well as cases that were not part of the final, matched datasets.

*** STACK VOTE HISTORY FILES
use "..\ccap0001_yal_post_lvecon_vh_output.dta", clear
save "..\VH1.dta", replace
use "..\ccap0001_yal_post_vh_output.dta", clear
save "..\VH2.dta", replace
append using ..\VH1.dta
drop profile59
save "..\VH_STACKED.dta", replace

*LOAD YALE PRIVATE CONTENT #1
use "..\ccap0001_yal_extra_output_r2_1.dta", clear
recast float caseid, force
*drop everything except income and weight data
keep caseid psweight profile59
save "..\matchedsamp1.dta", replace

*Load Yale private content #2 to get weight and income data
use "..\ccap0001_yal_output_r2_1.dta", clear
recast float caseid, force
*rename income and weight measures so they don't cause problems with the data merging 
rename psweight psweight2
rename profile59 profile59_1
*drop everything except income and weight data
keep caseid psweight2 profile59_1
save "..\matchedsamp2.dta", replace
clear

*Merge stacked vote history into the matched (to target sample) samples
use "..\VH_STACKED.dta", clear
joinby caseid using "..\matchedsamp1.dta", unmatched(both)
gen mtchrd1=(_merge==3)
drop _merge
joinby caseid using "..\matchedsamp2.dta", unmatched(both)
gen mtchrd2=(_merge==3)
drop _merge
replace psweight=psweight2 if psweight==.
replace profile59=profile59_1 if profile59==.
gen matched=mtchrd1+mtchrd2

*** DROP CASES POLIMETRIX DID NOT MATCH TO VOTER ROLLS
drop if vh_matched!=1

** KEEP ONLY CASES CORRESPONDING TO DATA THAT PAIRS WITH MATCHED PRIVATE CONTENT FILES 
keep if matched==1

** Missing==> no turnout
recode vh_p2000 vh_g2000 vh_p2002 vh_g2002 vh_p2004 vh_g2004 vh_p2006 vh_g2006 (.=0)

*** DROP UNUSED VARIABLES
keep vh_p2000 vh_g2000 vh_p2002 vh_g2002 vh_p2004 vh_g2004 vh_p2006 vh_g2006 profile66 profile54 profile55 profile57 profile59 profile51 profile40-profile49 psweight

save "ccap_validated.dta", replace

*************************************
***** CCAP COMMON CONTENT ***********
*************************************
use "..\ccap0001_common_output_r2_1_missingnotset.dta", clear
keep profile66 profile54 profile55 profile57 profile59 profile51 profile40-profile49 psweight scap400_* ocap400_* profile73s profile73o
save "ccap_common.dta", replace

**************************************
***** CT SURVEY **********************
**************************************
clear
insheet using "..\637-5 - Yale 30K - Survey Data.csv"
sort cp30id
joinby cp30id using "..\cp30id_to_voter_history_final.dta", unmatched(master)
*cases without merges should have weight 1
replace weight=1 if _merge==1
drop _merge
keep r2a r2b r2c r2d r2e r2f r2g r2h r2i r2j r9 r10 r11 r12 r13 r29 yearborn r15 r16 r16b r17 r18 r19 r20 r21a r21b cp30id v2000g v2002g v2004g v2006g weight
*if not merged, replace turnout with 0.
foreach var in v2000g v2002g v2004g v2006g {
 replace `var'=0 if `var'==.
}
save "ct_survey.dta", replace
